#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'settings-dialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/cygdrive/d/cyg_pub/devel/octave/octave-5.1.0-1.x86_64/src/octave-5.1.0/libgui/src/settings-dialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settings-dialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__settings_dialog_t {
    QByteArrayData data[15];
    char stringdata0[242];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__settings_dialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__settings_dialog_t qt_meta_stringdata_octave__settings_dialog = {
    {
QT_MOC_LITERAL(0, 0, 23), // "octave::settings_dialog"
QT_MOC_LITERAL(1, 24, 18), // "apply_new_settings"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 14), // "get_octave_dir"
QT_MOC_LITERAL(4, 59, 20), // "get_file_browser_dir"
QT_MOC_LITERAL(5, 80, 7), // "get_dir"
QT_MOC_LITERAL(6, 88, 10), // "QLineEdit*"
QT_MOC_LITERAL(7, 99, 34), // "set_disabled_pref_file_browse..."
QT_MOC_LITERAL(8, 134, 7), // "disable"
QT_MOC_LITERAL(9, 142, 14), // "button_clicked"
QT_MOC_LITERAL(10, 157, 16), // "QAbstractButton*"
QT_MOC_LITERAL(11, 174, 6), // "button"
QT_MOC_LITERAL(12, 181, 19), // "import_shortcut_set"
QT_MOC_LITERAL(13, 201, 19), // "export_shortcut_set"
QT_MOC_LITERAL(14, 221, 20) // "default_shortcut_set"

    },
    "octave::settings_dialog\0apply_new_settings\0"
    "\0get_octave_dir\0get_file_browser_dir\0"
    "get_dir\0QLineEdit*\0"
    "set_disabled_pref_file_browser_dir\0"
    "disable\0button_clicked\0QAbstractButton*\0"
    "button\0import_shortcut_set\0"
    "export_shortcut_set\0default_shortcut_set"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__settings_dialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   60,    2, 0x08 /* Private */,
       4,    0,   61,    2, 0x08 /* Private */,
       5,    2,   62,    2, 0x08 /* Private */,
       7,    1,   67,    2, 0x08 /* Private */,
       9,    1,   70,    2, 0x08 /* Private */,
      12,    0,   73,    2, 0x08 /* Private */,
      13,    0,   74,    2, 0x08 /* Private */,
      14,    0,   75,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::settings_dialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        settings_dialog *_t = static_cast<settings_dialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->apply_new_settings(); break;
        case 1: _t->get_octave_dir(); break;
        case 2: _t->get_file_browser_dir(); break;
        case 3: _t->get_dir((*reinterpret_cast< QLineEdit*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 4: _t->set_disabled_pref_file_browser_dir((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->button_clicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 6: _t->import_shortcut_set(); break;
        case 7: _t->export_shortcut_set(); break;
        case 8: _t->default_shortcut_set(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (settings_dialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&settings_dialog::apply_new_settings)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject octave::settings_dialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_octave__settings_dialog.data,
      qt_meta_data_octave__settings_dialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::settings_dialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::settings_dialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__settings_dialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int octave::settings_dialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void octave::settings_dialog::apply_new_settings()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
